@@ -208,13 +208,13 @@ class Preferences:
                         if len(a) > 0:
                             p = a[0]
                             if len(a) == 2 and p in self.bool_prefs:
-                                self.bool_prefs[p] = (a[1] == 'True')
+                                self.setBool(p, a[1] == 'True')
                             elif len(a) == 2 and p in self.int_prefs:
-                                self.int_prefs[p] = max(
+                                self.setInt(p, max(
                                     self.int_prefs_min[p],
-                                    min(int(a[1]), self.int_prefs_max[p]))
+                                    min(int(a[1]), self.int_prefs_max[p])))
                             elif len(a) == 2 and p in self.string_prefs:
-                                self.string_prefs[p] = a[1]
+                                self.setString(p, a[1])
                             else:
                                 raise ValueError()
                     except ValueError:
@@ -237,13 +237,13 @@ class Preferences:
                 self._initFromTemplate(template[i])
                 i += 1
         elif template[0] == 'Boolean':
-            self.bool_prefs[template[1]] = template[2]
+            self.setBool(template[1], template[2])
         elif template[0] == 'Integer':
-            self.int_prefs[template[1]] = template[2]
+            self.setInt(template[1], template[2])
             self.int_prefs_min[template[1]] = template[4]
             self.int_prefs_max[template[1]] = template[5]
         elif template[0] in ['String', 'File', 'Font', 'Encoding']:
-            self.string_prefs[template[1]] = template[2]
+            self.setString(template[1], template[2])
 
     # callback used when a preference is toggled
     def _toggled_cb(self, widget, widgets, name):
@@ -273,11 +273,12 @@ class Preferences:
         accept = (dialog.run() == Gtk.ResponseType.OK)
         if accept:
             for k in self.bool_prefs:
-                self.bool_prefs[k] = widgets[k].get_active()
+                self.setBool(k, widgets[k].get_active())
             for k in self.int_prefs:
-                self.int_prefs[k] = widgets[k].get_value_as_int()
+                self.setInt(k, widgets[k].get_value_as_int())
             for k in self.string_prefs:
-                self.string_prefs[k] = utils.null_to_empty(widgets[k].get_text())
+                text = self._getWidgetText(widgets[k])
+                self.setString(k, utils.null_to_empty(text))
             try:
                 ss = []
                 for k, bool_value in self.bool_prefs.items():
@@ -306,11 +307,11 @@ class Preferences:
     def _buildPrefsDialog(self, parent, widgets, template):
         tpl_section = template[0]
         if tpl_section == 'FolderSet':
-            notebook = Gtk.Notebook.new()
+            notebook = Gtk.Notebook()
             notebook.set_border_width(10)
             i = 1
             while i < len(template):
-                label = Gtk.Label.new(template[i])
+                label = Gtk.Label(label=template[i])
                 i += 1
                 w = self._buildPrefsDialog(parent, widgets, template[i])
                 i += 1
@@ -319,7 +320,7 @@ class Preferences:
                 label.show()
             return notebook
 
-        table = Gtk.Grid.new()
+        table = Gtk.Grid()
         table.set_border_width(10)
         for i, tpl in enumerate(template[1:]):
             tpl_section = tpl[0]
@@ -329,45 +330,66 @@ class Preferences:
                 w.show()
             elif tpl_section == 'Boolean':
                 button = Gtk.CheckButton.new_with_mnemonic(tpl[3])
-                button.set_active(self.bool_prefs[tpl[1]])
+                button.set_active(self.getBool(tpl[1]))
                 widgets[tpl[1]] = button
                 table.attach(button, 1, i, 1, 1)
                 button.connect('toggled', self._toggled_cb, widgets, tpl[1])
                 button.show()
             else:
-                label = Gtk.Label.new(tpl[3] + ': ')
+                label = Gtk.Label(label=tpl[3] + ': ')
                 label.set_xalign(1.0)
                 label.set_yalign(0.5)
                 table.attach(label, 0, i, 1, 1)
                 label.show()
-                if tpl[0] in ['Font', 'Integer']:
-                    entry = Gtk.Box.new(Gtk.Orientation.HORIZONTAL, 0)
-                    if tpl[0] == 'Font':
+                if tpl_section in ['Font', 'Integer']:
+                    entry = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL, spacing=0)
+                    if tpl_section == 'Font':
                         button = Gtk.FontButton()
-                        button.set_font(self.string_prefs[tpl[1]])
+                        button.set_font(self.getString(tpl[1]))
                     else:
-                        button = Gtk.SpinButton.new(
-                            Gtk.Adjustment.new(self.int_prefs[tpl[1]], tpl[4], tpl[5], 1, 0, 0),
-                            1.0,
-                            0)
+                        adj = Gtk.Adjustment(
+                            value=self.getInt(tpl[1]),
+                            lower=tpl[4],
+                            upper=tpl[5],
+                            step_increment=1,
+                            page_increment=0,
+                            page_size=0)
+                        button = Gtk.SpinButton(
+                            adjustment=adj,
+                            climb_rate=1.0,
+                            digits=0)
                     widgets[tpl[1]] = button
                     entry.pack_start(button, False, False, 0)
                     button.show()
                 else:
-                    if tpl[0] == 'Encoding':
+                    if tpl_section == 'Encoding':
                         entry = utils.EncodingMenu(self)
                         entry.set_text(tpl[3])
-                    elif tpl[0] == 'File':
+                    elif tpl_section == 'File':
                         entry = _FileEntry(parent, tpl[3])
                     else:
-                        entry = Gtk.Entry.new()
+                        entry = Gtk.Entry()
                     widgets[tpl[1]] = entry
-                    entry.set_text(self.string_prefs[tpl[1]])
+                    entry.set_text(self.getString(tpl[1]))
                 table.attach(entry, 1, i, 1, 1)
                 entry.show()
             table.show()
         return table
 
+    def _getWidgetText(self, widget):
+        text = ""
+        if (
+            isinstance(widget, Gtk.Entry) or
+            isinstance(widget, utils.EncodingMenu) or
+            isinstance(widget, _FileEntry)
+        ):
+            text = widget.get_text()
+        elif isinstance(widget, Gtk.FontButton):
+            text = widget.get_font()
+        else:
+            raise TypeError(f"Don't know how to get text from type: {type(widget)}")
+        return text
+
     # get/set methods to manipulate the preference values
     def getBool(self, name: str) -> bool:
         return self.bool_prefs[name]
@@ -378,6 +400,9 @@ class Preferences:
     def getInt(self, name: str) -> int:
         return self.int_prefs[name]
 
+    def setInt(self, name: str, value: int) -> None:
+        self.int_prefs[name] = value
+
     def getString(self, name: str) -> str:
         return self.string_prefs[name]
 
@@ -388,10 +413,10 @@ class Preferences:
         return self.encodings
 
     def _getDefaultEncodings(self) -> List[str]:
-        return self.string_prefs['encoding_auto_detect_codecs'].split()
+        return self.getString('encoding_auto_detect_codecs').split()
 
     def getDefaultEncoding(self) -> str:
-        return self.string_prefs['encoding_default_codec']
+        return self.getString('encoding_default_codec')
 
     # attempt to convert a string to unicode from an unknown encoding
     def convertToUnicode(self, s):
@@ -443,11 +468,11 @@ class _FileEntry(Gtk.Box):
         Gtk.Box.__init__(self, orientation=Gtk.Orientation.HORIZONTAL)
         self.toplevel = parent
         self.title = title
-        self.entry = entry = Gtk.Entry.new()
+        self.entry = entry = Gtk.Entry()
         self.pack_start(entry, True, True, 0)
         entry.show()
-        button = Gtk.Button.new()
-        image = Gtk.Image.new()
+        button = Gtk.Button()
+        image = Gtk.Image()
         image.set_from_stock(Gtk.STOCK_OPEN, Gtk.IconSize.MENU)
         button.add(image)
         image.show()
